"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.removeKeysFromObject = removeKeysFromObject;

function objectPathMatcher(currentKey, objHierarchy = [], keysToBeRemoved = []) {
  const objPathKey = objHierarchy.length > 0 ? `${objHierarchy.join('.')}.${currentKey}` : currentKey;
  return keysToBeRemoved.some(key => {
    const isWildPath = /^\*/.test(key);

    if (isWildPath) {
      const newKey = key.replace(/\*\.?/, '');
      return objPathKey.includes(newKey);
    }

    return key === objPathKey;
  });
}
/*
    1) *.keyTobeRemoved -> means match every object path, this key will be removed
    2) don't need to account for object iteration, just object key path is enough in the key to be removed.
*/


function removeKeysFromObject(obj, keysToBeRemoved, prevKeys = []) {
  if (Array.isArray(obj)) {
    return obj.map(item => removeKeysFromObject(item, keysToBeRemoved, prevKeys));
  }

  if (obj && typeof obj === 'object') {
    const filteredKeyObject = {};
    const ObjectKeys = Object.keys(obj);

    for (const objectKey of ObjectKeys) {
      const isKeyToBeRemoved = objectPathMatcher(objectKey, prevKeys, keysToBeRemoved);

      if (!isKeyToBeRemoved) {
        filteredKeyObject[objectKey] = removeKeysFromObject(obj[objectKey], keysToBeRemoved, [...prevKeys, objectKey]);
      }
    }

    return filteredKeyObject;
  }

  return obj;
}